Internal Simulated Annealing Function
fct_sim_anneal(
x,
y,
k,
init_assign,
lambda,
temp,
mu,
eps,
accept_prob,
sim_N,
track,
anneal_iter = 1000,
verbose
)An updated clustering vector.
A matrix of predictors.
A matrix of responses.
The number of groups.
An initial clustering assignment.
A vector of penalization parameters.
The initial simulated annealing temperature, temp > 0.
The simulated annealing decrease temperature fraction. Once the best configuration cannot be improved, reduce the temperature to (mu)T, 0 < mu < 1.
The final simulated annealing temperature, eps > 0.
The simulated annealing probability of accepting a new assignment 0 < accept_prob < 1. When closer to 1, trial assignments will only be small perturbation of the current assignment. When closer to 0, trial assignments are closer to random.
The simulated annealing number of iterations for reaching equilibrium.
A likelihood tracking vector.
The maximum number of simulated annealing iterations.
A boolean indicating whether to print to screen.